@@ -96,7 +96,7 @@ namespace tnt
     }
   }
 
-  void HttpReply::send(unsigned ret, const char* msg)
+  void HttpReply::send(unsigned ret, const char* msg, bool ready)
   {
     std::string body = outstream.str();
 
@@ -108,13 +108,16 @@ namespace tnt
     if (!hasHeader(httpheader::server))
       setHeader(httpheader::server, httpheader::serverName);
 
-    tryCompress(body);
+    if (ready)
+    {
+      tryCompress(body);
 
-    if (!hasHeader(httpheader::connection))
-      setKeepAliveHeader();
+      if (!hasHeader(httpheader::connection))
+        setKeepAliveHeader();
 
-    if (!hasHeader(httpheader::contentLength))
-      setContentLengthHeader(body.size());
+      if (!hasHeader(httpheader::contentLength))
+        setContentLengthHeader(body.size());
+    }
 
     // send header
 
@@ -148,7 +151,12 @@ namespace tnt
     else
     {
       log_debug("send " << body.size() << " bytes body");
-      socket << body;
+      // We send in chunks just to leave to ostream operator from time to time.
+      // There are iostream libraries, which do have a global lock, which
+      // block other iostreams while writing.
+      const unsigned chunkSize = 65536;
+      for (unsigned n = 0; n < body.size(); n += chunkSize)
+        socket.write(body.data() + n, std::min(static_cast<unsigned>(body.size() - n), chunkSize));
     }
   }
 
@@ -168,7 +176,7 @@ namespace tnt
   {
     if (!isDirectMode())
     {
-      send(ret, msg);
+      send(ret, msg, true);
       socket.flush();
     }
   }
@@ -220,7 +228,7 @@ namespace tnt
   {
     if (!isDirectMode())
     {
-      send(ret, msg);
+      send(ret, msg, false);
       current_outstream = &socket;
       safe_outstream.setSink(socket);
     }
