@@ -41,7 +41,7 @@ namespace tnt
       { }
 
       virtual unsigned operator() (tnt::HttpRequest& request,
-        tnt::HttpReply& reply, cxxtools::QueryParams& qparam);
+        tnt::HttpReply& reply, tnt::QueryParams& qparam);
   };
 
   ////////////////////////////////////////////////////////////////////////
@@ -69,7 +69,7 @@ namespace tnt
   // componentdefinition
   //
   unsigned Error::operator() (tnt::HttpRequest& request,
-    tnt::HttpReply& reply, cxxtools::QueryParams&)
+    tnt::HttpReply& reply, tnt::QueryParams&)
   {
     std::string msg;
 
